# kuro.py

Async API wrapper for KuroBBS written in Python

## Setting up the development environment

```bash
# Clone the repo
git clone https://github.com/Wuthery/kuro.py

# Install the dependencies
cd kuro.py
poetry install --with dev

# If you want to run the tests locally
poetry install --with test

# Install pre-commit
pre-commit install
```
